BibleReference class abstract

Base class for all reference objects.

Implementers

Constructors

BibleReference(String book)
Constructs the BibleReference as a reference to a book.

Properties

abbrBook → String?
The uppercased paratext abbreviation for this reference's book.
no setter
abbrReference → String?
The uppercased paratext abbreviation for this reference.
no setter
book → String
The full book name of the reference.
final
bookNumber → int?
The book number for the passed in reference book.
final
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
Whether the reference is in the bible.
final
osisBook → String?
The title cased representation for this reference's book.
no setter
osisReference → String?
The title cased representation for this reference.
no setter
reference → String?
The representation of the reference.
final
referenceType → ReferenceType?
The type of reference.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortBook → String?
The shortest standard abbreviation for this reference's book.
no setter
shortReference → String?
The shortest standard abbreviation for this reference.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns BibleReference.reference
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited