Librarian class

A grouping of fields that parse strings and numbers to create reference objects or return information on certain bible properties.

Uses the BibleData class extensively.

Constructors

Librarian()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkBook(String book) → bool
Validate that a book is in the bible, does not validate mispellings.
createReferenceString(String? book, [int? startChapter, int? startVerse, int? endChapter, int? endVerse]) → String?
Creates a String reference based on which fields are left null.
findBookNumber(String book) → int?
Returns the book number from a string.
getBookNames(dynamic book) → Map<String, String>
Returns the osis, abbr, name, and short versions of a book title.
getLastChapter(dynamic book) → Chapter?
Returns a Chapter object that corresponds to the last chapter within a book.
getLastChapterNumber(dynamic book) → int?
Returns the number for the last chapter within a book.
getLastVerse(dynamic book, [int? chapter]) → Verse?
Creates a Verse object for the last verse in a book or chapter.
getLastVerseNumber(dynamic book, [int? chapter]) → int?
Gets the last verse number in a specified book or book or chapter.
identifyReferenceType(dynamic book, [dynamic startChapter, dynamic startVerse, dynamic endChapter, dynamic endVerse]) → ReferenceType?
Returns the ReferenceType based on the number of passed in arguments.
verifyReference(dynamic book, [int? startChapter, int? startVerse, dynamic endChapter, dynamic endVerse]) → bool
Verifies a reference based on which fields are left null or can be found within the bible.